import { JsonValue, Value } from './value';
/**
 * Matches a JSON array.
 */
export interface JsonArray extends Array<JsonValue> {
}
/**
 * @typedef {Object} ListValue
 * @property {Value[]} values The list values.
 */
export interface ListValue {
    values?: Value[];
}
/**
 * Used to encode/decode {@link ListValue} objects.
 */
export declare const list: {
    /**
     * Encodes an array of JSON values into a protobuf {@link ListValue}.
     *
     * @param {Array.<*>} values the JSON values.
     * @returns {ListValue}
     */
    encode(values: JsonArray): ListValue;
    /**
     * Decodes a protobuf {@link ListValue} into an array of JSON values.
     *
     * @param {ListValue} list the protobuf list value.
     * @returns {Array.<*>}
     */
    decode({ values }: ListValue): JsonArray;
};
